@@ -7,6 +7,9 @@
 #if (NETTLE_VERSION_MAJOR != 3)
 #error unsupported nettle version
 #endif
+#if (NETTLE_VERSION_MAJOR == 3 && NETTLE_VERSION_MINOR < 2)
+#error SHA-3 interface broke compat in 3.2; earlier versions not supported
+#endif
 
 #include <sys/types.h>
 #include <nettle/cbc.h>
@@ -25,9 +28,4 @@
 
 #include <nettle/umac.h>
 
-void hs_nettle_sha3_224_digest(struct sha3_224_ctx *ctx, size_t length, uint8_t *digest);
-void hs_nettle_sha3_256_digest(struct sha3_256_ctx *ctx, size_t length, uint8_t *digest);
-void hs_nettle_sha3_384_digest(struct sha3_384_ctx *ctx, size_t length, uint8_t *digest);
-void hs_nettle_sha3_512_digest(struct sha3_512_ctx *ctx, size_t length, uint8_t *digest);
-
 #endif
